Documentation
¶
Overview ¶
Package mustr is guaranteed to only export symbols starting with word Must or R. It is intended to be used in tests via dot-import:
import (
"testing"
. "import.name/testing/mustr"
)
func example() (int, error)
func Test(t *testing.T) {
_ = Must(t, R(example()))
}
Test fails immediately if example returns an error.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.